@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use Module::New::File;
 
-file 't/99_podcoverage.t' => content { return <<'EOT';
+file 'xt/99_podcoverage.t' => content { return <<'EOT';
 use strict;
 use warnings;
 use Test::More;
 
 eval "use Test::Pod::Coverage 1.04";
 plan skip_all => 'Test::Pod::Coverage 1.04 required' if $@;
-plan skip_all => 'set TEST_POD to enable this test' unless $ENV{TEST_POD};
+plan skip_all => 'set TEST_POD to enable this test' unless $ENV{RELEASE_TESTING};
 
 all_pod_coverage_ok();
 EOT
